'use strict';

const helper    = require('./test-helper');
const expect    = require('chai').expect;
const miniprism = require('../src/miniprism');
const strTimes  = helper.strTimes;
const e         = helper.e;

describe('headings', function() {
  [1, 2, 3, 4, 5, 6].forEach(function testHeading(level) {
    it('parses h' + level + ' headings', function() {
      const source = `${strTimes('#', level)} Hello`;
      const actual = miniprism.highlight(source, 'markdown');

      expect(actual).to.eql(e([
        `.md-h${level}.md-has-folding.md-line>`,
          `span.md-hash.md-folding{${strTimes('#', level)} }+`,
          `{Hello}`
      ].join('')));
    });
  });

  it('does not parse "h7" headings', function() {
    const source = '####### Hello world';
    const actual = miniprism.highlight(source, 'markdown');

    expect(actual).to.eql(e('.md-p.md-line{####### Hello world}'));
  });

  it('allows for headers to follow paragraphs', function() {
    const source = 'Foo\n# Header';
    const actual = miniprism.highlight(source, 'markdown');

    expect(actual).to.eql(e([
      `.md-p.md-line{Foo}+`,
      `.md-h1.md-has-folding.md-line>`,
        `span.md-hash.md-folding{# }+`,
        `{Header}`,
    ].join('')));
  });

  it('parses h1 setex headers', function() {
    const source = 'Hello\n=';
    const actual = miniprism.highlight(source, 'markdown');

    expect(actual).to.eql(e([
      `.md-setex-h1.md-line>`,
        `.md-setex-header.md-line{Hello}+`,
        `.md-setex-marker.md-line{=}+`,
    ].join('')));
  });

  it('parses h2 setex headers', function() {
    const source = 'Hello\n-';
    const actual = miniprism.highlight(source, 'markdown');

    expect(actual).to.eql(e([
      `.md-setex-h2.md-line>`,
        `.md-setex-header.md-line{Hello}+`,
        `.md-setex-marker.md-line{-}+`,
    ].join('')));
  });

  it('does not parse list items as setex headers', function() {
    var source = '- Hello\n-';
    var actual = miniprism.highlight(source, 'markdown');
    expect(actual).to.eql([
      '<div class="md-ul md-has-folding md-line">',
        '<span class="md-ul-marker md-folding">- </span>Hello',
      '</div>',
      '<div class="md-p md-line">-</div>'
    ].join(''));
  });

});
